pub struct AvcDecoderConfigurationRecord<'buf> { /* private fields */ }Implementations
Sourceimpl<'buf> AvcDecoderConfigurationRecord<'buf>
impl<'buf> AvcDecoderConfigurationRecord<'buf>
pub fn configuration_version(&self) -> u8
pub fn num_of_sequence_parameter_sets(&self) -> usize
pub fn avc_profile_indication(&self) -> ProfileIdc
pub fn profile_compatibility(&self) -> ConstraintFlags
pub fn avc_level_indication(&self) -> Level
Sourcepub fn length_size_minus_one(&self) -> u8
pub fn length_size_minus_one(&self) -> u8
Number of bytes used to specify the length of each NAL unit 0 => 1 byte, 1 => 2 bytes, 2 => 3 bytes, 3 => 4 bytes
pub fn sequence_parameter_sets( &self, ) -> impl Iterator<Item = Result<&'buf [u8], ParamSetError>>
Sourcepub fn chroma_format(&self) -> Option<u8>
pub fn chroma_format(&self) -> Option<u8>
Returns the chroma format (0-3) from the extension fields, if present.
Sourcepub fn bit_depth_luma_minus8(&self) -> Option<u8>
pub fn bit_depth_luma_minus8(&self) -> Option<u8>
Returns bit_depth_luma_minus8 (0-7) from the extension fields, if present.
Sourcepub fn bit_depth_chroma_minus8(&self) -> Option<u8>
pub fn bit_depth_chroma_minus8(&self) -> Option<u8>
Returns bit_depth_chroma_minus8 (0-7) from the extension fields, if present.
pub fn sequence_parameter_set_extensions( &self, ) -> impl Iterator<Item = Result<&'buf [u8], ParamSetError>> + 'buf
pub fn picture_parameter_sets( &self, ) -> impl Iterator<Item = Result<&'buf [u8], ParamSetError>> + 'buf
Sourcepub fn create_context(&self) -> Result<Context, AvccError>
pub fn create_context(&self) -> Result<Context, AvccError>
Creates an H264 parser context, using the settings encoded into
this AvcDecoderConfigurationRecord.
In particular, the sequence parameter set and picture parameter set values of this configuration record will be inserted into the resulting context.