pub trait AccumulatedNalHandler {
// Required method
fn nal(&mut self, nal: RefNal<'_>) -> NalInterest;
}Expand description
NalAccumulator callback which handles partially- or completely-buffered NALs.
The simplest handler is a closure. Implement this type manually when you your handler to own state which can be accessed via NalAccumulator::handler, NalAccumulator::handler_mut, or NalAccumulator::into_handler.
Required Methods
fn nal(&mut self, nal: RefNal<'_>) -> NalInterest
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".