pub struct Context { /* private fields */ }Expand description
Contextual data that needs to be tracked between evaluations of different portions of H264 syntax.
Implementations
Sourceimpl Context
impl Context
pub fn new() -> Self
pub fn sps_by_id(&self, id: SeqParamSetId) -> Option<&SeqParameterSet>
pub fn sps(&self) -> impl Iterator<Item = &SeqParameterSet>
pub fn put_seq_param_set(&mut self, sps: SeqParameterSet)
pub fn pps_by_id(&self, id: PicParamSetId) -> Option<&PicParameterSet>
pub fn pps(&self) -> impl Iterator<Item = &PicParameterSet>
pub fn put_pic_param_set(&mut self, pps: PicParameterSet)
pub fn subset_sps_by_id(&self, id: SeqParamSetId) -> Option<&SubsetSps>
pub fn subset_sps(&self) -> impl Iterator<Item = &SubsetSps>
Sourcepub fn put_subset_seq_param_set(&mut self, subset: SubsetSps)
pub fn put_subset_seq_param_set(&mut self, subset: SubsetSps)
Stores a subset SPS and also registers its base SPS in the regular SPS map
so that PPS and slice header parsing can find it via sps_by_id().