pub enum PrimaryPicType {
I = 0,
IP = 1,
IPB = 2,
SI = 3,
SISP = 4,
ISI = 5,
ISIPSP = 6,
ISIPSPB = 7,
}Expand description
Indicates which slice types may be present in the primary coded picture of the access unit (Table 7-5).
Variants
I = 0
I slices only
IP = 1
I, P slices
IPB = 2
I, P, B slices
SI = 3
SI slices only
SISP = 4
SI, SP slices
ISI = 5
I, SI slices
ISIPSP = 6
I, SI, P, SP slices
ISIPSPB = 7
I, SI, P, SP, B slices
Implementations
Sourceimpl PrimaryPicType
impl PrimaryPicType
pub fn from_id(id: u8) -> Result<PrimaryPicType, PrimaryPicTypeError>
pub fn id(self) -> u8